@@ -49,7 +49,7 @@ qz.dgees <- function(A, vs = TRUE, LWORK = NULL){
   }
   WORK <- double(LWORK)
 
-  BWORK <- integer(1)                # WCC: TODO, no effect if SORT = "N".
+  BWORK <- integer(N)                # WCC: TODO, no effect if SORT = "N".
 
   INFO <- integer(1)
 
