@@ -9,12 +9,12 @@ static int fake_select(Rcomplex *w){
 SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 		SEXP A, SEXP LDA, SEXP SDIM,
 		SEXP W, SEXP VS, SEXP LDVS,
-		SEXP WORK, SEXP LWORK, SEXP RWORK, SEXP BWORK,
+		SEXP WORK, SEXP LWORK, SEXP RWORK, SEXP IBWORK,
 		SEXP INFO){
 	int n = INTEGER(N)[0], total_length;
 	SEXP RET, RET_NAMES, T;
 	char CS_JOBVS = CHARPT(JOBVS, 0)[0], CS_SORT = CHARPT(SORT, 0)[0];
-	int CF_wrap;
+	int CF_iwrap;
 
 	/* Protect R objects. */
 	PROTECT(RET = allocVector(VECSXP, 1));
@@ -31,17 +31,17 @@ SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVS == 'V' && CS_SORT == 'N'){
-		CF_wrap = 0;
+		CF_iwrap = 0;
 	} else if(CS_JOBVS == 'N' && CS_SORT == 'N'){
-		CF_wrap = 1;
+		CF_iwrap = 1;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
-	F77_CALL(wzgees)(&CF_wrap,
+	F77_CALL(wzgees)(&CF_iwrap,
 		fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
 		INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
 		COMPLEX(WORK), INTEGER(LWORK),
-		REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		REAL(RWORK), INTEGER(IBWORK), INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(3);
